pyproject_metadata: PEP 621 metadata parsing
============================================

Description
-----------

PEP 621 metadata parsing

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pyproject-metadata/

